pyparsing.pyparsing._ParseResultsWithOffset

Package pyparsing :: Module pyparsing :: Class _ParseResultsWithOffset |
[hide private]
[frames] | no frames]

# Class _ParseResultsWithOffset

source code

    object --+
             |
            _ParseResultsWithOffset

Instance Methods | [hide private]
__init__(self, p1, p2) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__getitem__(self, i) | source code
__repr__(self) repr(x) | source code
setOffset(self, i) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, p1, p2) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)